@@ -25,7 +25,6 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <util.h>
-/*@unused@*/ RCSID("$Id: yasm.c 2317 2010-04-08 06:10:16Z peter $");
 
 #include <ctype.h>
 #include <libyasm/compat-queue.h>
@@ -213,9 +212,9 @@ static opt_option options[] =
 
 /* version message */
 /*@observer@*/ static const char *version_msg[] = {
-    PACKAGE_NAME " " PACKAGE_INTVER "." PACKAGE_BUILD,
+    PACKAGE_STRING,
     "Compiled on " __DATE__ ".",
-    "Copyright (c) 2001-2010 Peter Johnson and other Yasm developers.",
+    "Copyright (c) 2001-2011 Peter Johnson and other Yasm developers.",
     "Run yasm --license for licensing overview and summary."
 };
 
